//Asic.h: interface of spicall;
/* sane - Scanner Access Now Easy.

   Copyright (C) 2005 Mustek.
   Originally maintained by Mustek
   Author:Roy 2005.5.24

   This file is part of the SANE package.

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330, Boston,
   MA 02111-1307, USA.

   As a special exception, the authors of SANE give permission for
   additional uses of the libraries contained in this release of SANE.

   The exception is that, if you link a SANE library with other files
   to produce an executable, this does not by itself cause the
   resulting executable to be covered by the GNU General Public
   License.  Your use of that executable is in no way restricted on
   account of linking the SANE library code into it.

   This exception does not, however, invalidate any other reasons why
   the executable file might be covered by the GNU General Public
   License.

   If you submit changes to SANE to the maintainers to be included in
   a subsequent release, you agree by submitting the changes that
   those changes may be distributed with this exception intact.

   If you write modifications of your own for SANE, it is your choice
   whether to permit this exception to apply to your modifications.
   If you do not wish that, delete this exception notice.

   This file implements a SANE backend for Mustek 1200UB and similar 
   USB flatbed scanners.  */

#ifndef _ASIC_
#define _ASIC_
#include "typedef.h"
#include "public.h"

// Open Scanner by Scanner Name and return Chip Information
STATUS Asic_Open(PAsic chip, LPSTR pDeviceName);

// Close Scanner
STATUS Asic_Close(PAsic chip);

// Release Scanner Resource 
STATUS Asic_Release(PAsic chip);

// Initialize Scanner Parameters
STATUS Asic_Initialize(PAsic chip);

// Set Scan Window
STATUS Asic_SetWindow(PAsic chip, BYTE bScanBits, 
				 WORD wXResolution, WORD wYResolution, 
				 WORD wX, WORD wY, WORD wWidth, WORD wLength);

// Turn Lamp  ON or OFF
STATUS Asic_TurnLamp(PAsic chip, BOOL isLampOn);

// Turn TA ON or OFF
STATUS Asic_TurnTA(PAsic chip, BOOL isTAOn);

//Reset some parameter of asic
STATUS Asic_Reset(PAsic chip);

//Set scan source
STATUS Asic_SetSource(PAsic chip, LIGHTSOURCE lsLightSource);

// Start scanner to scan
STATUS Asic_ScanStart(PAsic chip);

// Stop scanner to scan
STATUS Asic_ScanStop(PAsic chip);

// Read One Scan Line When Scanning
STATUS Asic_ReadImage(PAsic chip, LPBYTE pBuffer, 
										WORD LinesCount);

// To Check Hard Key
STATUS Asic_CheckFunctionKey(PAsic chip,LPBYTE key);

// To Check if TA id connected
STATUS Asic_IsTAConnected(PAsic chip,PBOOL hasTA);


// Download GammaTable to Scanner
STATUS Asic_DownloadGammaTable(PAsic chip, LPVOID lpBuffer);

// For AdjustAD Calculate Scanner
STATUS Asic_ReadCalibrationData(PAsic chip, LPVOID pBuffer, 
								DWORD dwXferBytes,BYTE bScanBits);

//Set motor move or not
STATUS Asic_SetMotorType(PAsic chip, 
						BOOL isMotorMove,BOOL isUniformSpeed);

// Move Motor Forward or Backword
STATUS Asic_MotorMove(PAsic chip, BOOL isForward,DWORD dwTotalSteps);

// Move Motor to Home. 
//If isTA is TRUE, move TA to home, else move Lamp to home
STATUS Asic_CarriageHome(PAsic chip, BOOL isTA);

//For ShadingTable
STATUS Asic_SetShadingTable(PAsic chip, LPWORD lpWhiteShading, 
								LPWORD lpDarkShading, 
								WORD wXResolution, WORD wWidth, 
								WORD wX);

// Wait motor move to home.
//isTA no used
STATUS Asic_WaitCarriageHome(PAsic chip, BOOL isTA);

//Wait until asic idle
STATUS Asic_WaitUnitReady(PAsic chip);

// Set Scan Parameter to Scanner
STATUS Asic_SetCalibrate(PAsic chip,BYTE bScanBits, WORD wXResolution, 
						 WORD wYResolution, WORD wX, WORD wY, 
						 WORD wWidth, WORD wLength, BOOL isShading);

//Set AFE  Parameter to Scanner
STATUS Asic_SetAFEGainOffset(PAsic chip);

#endif /* End of file asic.h */
